@@ -27,10 +27,11 @@ else:
 
 from google.ads.googleads.client import GoogleAdsClient
 from google.ads.googleads.errors import GoogleAdsException
-from google.ads.googleads.v8.services.types.google_ads_service import GoogleAdsRow
+from google.ads.googleads.v10.services.services.customer_service import CustomerServiceClient
+from google.ads.googleads.v10.services.services.google_ads_service import GoogleAdsServiceClient
+from google.ads.googleads.v10.services.types.google_ads_service import GoogleAdsRow, SearchGoogleAdsRequest
 from google.api_core.page_iterator import GRPCIterator
 from google.auth.exceptions import GoogleAuthError
-from googleapiclient.discovery import Resource
 
 from airflow import AirflowException
 from airflow.hooks.base import BaseHook
@@ -51,12 +52,12 @@ class GoogleAdsHook(BaseHook):
             {
                 "google_ads_client": {
                     "developer_token": "{{ INSERT_TOKEN }}",
-                    "path_to_private_key_file": null,
-                    "delegated_account": "{{ INSERT_DELEGATED_ACCOUNT }}"
+                    "json_key_file_path": null,
+                    "impersonated_email": "{{ INSERT_IMPERSONATED_EMAIL }}"
                 }
             }
 
-        The ``path_to_private_key_file`` is resolved by the hook using credentials from gcp_conn_id.
+        The ``json_key_file_path`` is resolved by the hook using credentials from gcp_conn_id.
         https://developers.google.com/google-ads/api/docs/client-libs/python/oauth-service
 
     .. seealso::
@@ -75,7 +76,7 @@ class GoogleAdsHook(BaseHook):
     :rtype: list[GoogleAdsRow]
     """
 
-    default_api_version = "v8"
+    default_api_version = "v10"
 
     def __init__(
         self,
@@ -155,13 +156,13 @@ class GoogleAdsHook(BaseHook):
             raise
 
     @cached_property
-    def _get_service(self) -> Resource:
+    def _get_service(self) -> GoogleAdsServiceClient:
         """Connects and authenticates with the Google Ads API using a service account"""
         client = self._get_client
         return client.get_service("GoogleAdsService", version=self.api_version)
 
     @cached_property
-    def _get_client(self) -> Resource:
+    def _get_client(self) -> GoogleAdsClient:
         with NamedTemporaryFile("w", suffix=".json") as secrets_temp:
             self._get_config()
             self._update_config_with_secret(secrets_temp)
@@ -173,7 +174,7 @@ class GoogleAdsHook(BaseHook):
                 raise
 
     @cached_property
-    def _get_customer_service(self) -> Resource:
+    def _get_customer_service(self) -> CustomerServiceClient:
         """Connects and authenticates with the Google Ads API using a service account"""
         with NamedTemporaryFile("w", suffix=".json") as secrets_temp:
             self._get_config()
@@ -207,7 +208,7 @@ class GoogleAdsHook(BaseHook):
         secrets_temp.write(secret)
         secrets_temp.flush()
 
-        self.google_ads_config["path_to_private_key_file"] = secrets_temp.name
+        self.google_ads_config["json_key_file_path"] = secrets_temp.name
 
     def _search(
         self, client_ids: List[str], query: str, page_size: int = 10000, **kwargs
@@ -226,7 +227,7 @@ class GoogleAdsHook(BaseHook):
 
         iterators = []
         for client_id in client_ids:
-            request = self._get_client.get_type("SearchGoogleAdsRequest")
+            request = self._get_client.get_type("SearchGoogleAdsRequest")  # type: SearchGoogleAdsRequest
             request.customer_id = client_id
             request.query = query
             request.page_size = page_size
