@@ -19,17 +19,16 @@ import os
 import sys
 from typing import Collection, Optional
 
+from airflow.providers.google.common.consts import CLIENT_INFO
+
 if sys.version_info >= (3, 8):
     from functools import cached_property
 else:
     from cached_property import cached_property
 
-from google.api_core.client_info import ClientInfo
-
 # not sure why but mypy complains on missing `storage` but it is clearly there and is importable
 from google.cloud import storage  # type: ignore[attr-defined]
 
-from airflow import version
 from airflow.providers.google.cloud.utils.credentials_provider import get_credentials_and_project_id
 from airflow.utils.log.file_task_handler import FileTaskHandler
 from airflow.utils.log.logging_mixin import LoggingMixin
@@ -49,25 +48,18 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
     failure, it reads from host machine's local disk.
 
     :param base_log_folder: Base log folder to place logs.
-    :type base_log_folder: str
     :param gcs_log_folder: Path to a remote location where logs will be saved. It must have the prefix
         ``gs://``. For example: ``gs://bucket/remote/log/location``
-    :type gcs_log_folder: str
     :param filename_template: template filename string
-    :type filename_template: str
     :param gcp_key_path: Path to Google Cloud Service Account file (JSON). Mutually exclusive with
         gcp_keyfile_dict.
         If omitted, authorization based on `the Application Default Credentials
         <https://cloud.google.com/docs/authentication/production#finding_credentials_automatically>`__ will
         be used.
-    :type gcp_key_path: str
     :param gcp_keyfile_dict: Dictionary of keyfile parameters. Mutually exclusive with gcp_key_path.
-    :type gcp_keyfile_dict: dict
     :param gcp_scopes: Comma-separated string containing OAuth2 scopes
-    :type gcp_scopes: str
     :param project_id: Project ID to read the secrets from. If not passed, the project ID from credentials
         will be used.
-    :type project_id: str
     """
 
     def __init__(
@@ -75,7 +67,7 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
         *,
         base_log_folder: str,
         gcs_log_folder: str,
-        filename_template: str,
+        filename_template: Optional[str] = None,
         gcp_key_path: Optional[str] = None,
         gcp_keyfile_dict: Optional[dict] = None,
         gcp_scopes: Optional[Collection[str]] = _DEFAULT_SCOPESS,
@@ -103,7 +95,7 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
         )
         return storage.Client(
             credentials=credentials,
-            client_info=ClientInfo(client_library_version='airflow_v' + version.version),
+            client_info=CLIENT_INFO,
             project=self.project_id if self.project_id else project_id,
         )
 
@@ -174,9 +166,7 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
         was created.
 
         :param log: the log to write to the remote_log_location
-        :type log: str
         :param remote_log_location: the log's location in remote storage
-        :type remote_log_location: str (path)
         """
         try:
             blob = storage.Blob.from_string(remote_log_location, self.client)
