@@ -24,7 +24,9 @@ from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator, Connection
 from airflow.providers.google.cloud.hooks.cloud_sql import CloudSQLDatabaseHook, CloudSQLHook
+from airflow.providers.google.cloud.links.cloud_sql import CloudSQLInstanceDatabaseLink, CloudSQLInstanceLink
 from airflow.providers.google.cloud.utils.field_validator import GcpBodyFieldValidator
+from airflow.providers.google.common.links.storage import FileDetailsLink
 from airflow.providers.mysql.hooks.mysql import MySqlHook
 from airflow.providers.postgres.hooks.postgres import PostgresHook
 
@@ -151,9 +153,26 @@ CLOUD_SQL_EXPORT_VALIDATION = [
                 fields=[
                     dict(name="tables", optional=True, type="list"),
                     dict(name="schemaOnly", optional=True),
+                    dict(
+                        name="mysqlExportOptions",
+                        type="dict",
+                        optional=True,
+                        fields=[dict(name="masterData")],
+                    ),
+                ],
+            ),
+            dict(
+                name="csvExportOptions",
+                type="dict",
+                optional=True,
+                fields=[
+                    dict(name="selectQuery"),
+                    dict(name="escapeCharacter", optional=True),
+                    dict(name="quoteCharacter", optional=True),
+                    dict(name="fieldsTerminatedBy", optional=True),
+                    dict(name="linesTerminatedBy", optional=True),
                 ],
             ),
-            dict(name="csvExportOptions", type="dict", optional=True, fields=[dict(name="selectQuery")]),
             dict(name="offload", optional=True),
         ],
     )
@@ -299,6 +318,8 @@ class CloudSQLCreateInstanceOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_create_template_fields]
+    ui_color = '#FADBDA'
+    operator_extra_links = (CloudSQLInstanceLink(),)
 
     def __init__(
         self,
@@ -346,6 +367,13 @@ class CloudSQLCreateInstanceOperator(CloudSQLBaseOperator):
         else:
             self.log.info("Cloud SQL instance with ID %s already exists. Aborting create.", self.instance)
 
+        CloudSQLInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            cloud_sql_instance=self.instance,
+            project_id=self.project_id or hook.project_id,
+        )
+
         instance_resource = hook.get_instance(project_id=self.project_id, instance=self.instance)
         service_account_email = instance_resource["serviceAccountEmailAddress"]
         task_instance = context['task_instance']
@@ -394,6 +422,8 @@ class CloudSQLInstancePatchOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_patch_template_fields]
+    ui_color = '#FBDAC8'
+    operator_extra_links = (CloudSQLInstanceLink(),)
 
     def __init__(
         self,
@@ -433,6 +463,13 @@ class CloudSQLInstancePatchOperator(CloudSQLBaseOperator):
                 'Please specify another instance to patch.'
             )
         else:
+            CloudSQLInstanceLink.persist(
+                context=context,
+                task_instance=self,
+                cloud_sql_instance=self.instance,
+                project_id=self.project_id or hook.project_id,
+            )
+
             return hook.patch_instance(project_id=self.project_id, body=self.body, instance=self.instance)
 
 
@@ -468,6 +505,7 @@ class CloudSQLDeleteInstanceOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_delete_template_fields]
+    ui_color = '#FEECD2'
 
     def execute(self, context: 'Context') -> Optional[bool]:
         hook = CloudSQLHook(
@@ -518,6 +556,8 @@ class CloudSQLCreateInstanceDatabaseOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_db_create_template_fields]
+    ui_color = '#FFFCDB'
+    operator_extra_links = (CloudSQLInstanceDatabaseLink(),)
 
     def __init__(
         self,
@@ -568,6 +608,12 @@ class CloudSQLCreateInstanceDatabaseOperator(CloudSQLBaseOperator):
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
+        CloudSQLInstanceDatabaseLink.persist(
+            context=context,
+            task_instance=self,
+            cloud_sql_instance=self.instance,
+            project_id=self.project_id or hook.project_id,
+        )
         if self._check_if_db_exists(database, hook):
             self.log.info(
                 "Cloud SQL instance with ID %s already contains database '%s'. Aborting database insert.",
@@ -618,6 +664,8 @@ class CloudSQLPatchInstanceDatabaseOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_db_patch_template_fields]
+    ui_color = '#ECF4D9'
+    operator_extra_links = (CloudSQLInstanceDatabaseLink(),)
 
     def __init__(
         self,
@@ -670,6 +718,12 @@ class CloudSQLPatchInstanceDatabaseOperator(CloudSQLBaseOperator):
                 "Please specify another database to patch."
             )
         else:
+            CloudSQLInstanceDatabaseLink.persist(
+                context=context,
+                task_instance=self,
+                cloud_sql_instance=self.instance,
+                project_id=self.project_id or hook.project_id,
+            )
             return hook.patch_database(
                 project_id=self.project_id, instance=self.instance, database=self.database, body=self.body
             )
@@ -709,6 +763,7 @@ class CloudSQLDeleteInstanceDatabaseOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_db_delete_template_fields]
+    ui_color = '#D5EAD8'
 
     def __init__(
         self,
@@ -794,6 +849,8 @@ class CloudSQLExportInstanceOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_export_template_fields]
+    ui_color = '#D4ECEA'
+    operator_extra_links = (CloudSQLInstanceLink(), FileDetailsLink())
 
     def __init__(
         self,
@@ -836,6 +893,18 @@ class CloudSQLExportInstanceOperator(CloudSQLBaseOperator):
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
+        CloudSQLInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            cloud_sql_instance=self.instance,
+            project_id=self.project_id or hook.project_id,
+        )
+        FileDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            uri=self.body["exportContext"]["uri"][5:],
+            project_id=self.project_id or hook.project_id,
+        )
         return hook.export_instance(project_id=self.project_id, instance=self.instance, body=self.body)
 
 
@@ -891,6 +960,8 @@ class CloudSQLImportInstanceOperator(CloudSQLBaseOperator):
         'impersonation_chain',
     )
     # [END gcp_sql_import_template_fields]
+    ui_color = '#D3EDFB'
+    operator_extra_links = (CloudSQLInstanceLink(), FileDetailsLink())
 
     def __init__(
         self,
@@ -933,6 +1004,18 @@ class CloudSQLImportInstanceOperator(CloudSQLBaseOperator):
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
+        CloudSQLInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            cloud_sql_instance=self.instance,
+            project_id=self.project_id or hook.project_id,
+        )
+        FileDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            uri=self.body["importContext"]["uri"][5:],
+            project_id=self.project_id or hook.project_id,
+        )
         return hook.import_instance(project_id=self.project_id, instance=self.instance, body=self.body)
 
 
@@ -966,6 +1049,7 @@ class CloudSQLExecuteQueryOperator(BaseOperator):
     template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'sql': 'sql'}
     # [END gcp_sql_query_template_fields]
+    ui_color = '#D3DEF1'
 
     def __init__(
         self,
