@@ -21,6 +21,7 @@ from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Union
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
+from airflow.providers.google.cloud.links.bigquery import BigQueryTableLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -39,35 +40,23 @@ class BigQueryToBigQueryOperator(BaseOperator):
         source data. If ``<project>`` is not included, project will be the
         project defined in the connection json. Use a list if there are multiple
         source tables. (templated)
-    :type source_project_dataset_tables: list|string
     :param destination_project_dataset_table: The destination BigQuery
         table. Format is: ``(project:|project.)<dataset>.<table>`` (templated)
-    :type destination_project_dataset_table: str
     :param write_disposition: The write disposition if the table already exists.
-    :type write_disposition: str
     :param create_disposition: The create disposition if the table doesn't exist.
-    :type create_disposition: str
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
-    :param bigquery_conn_id: (Deprecated) The connection ID used to connect to Google Cloud.
-        This parameter has been deprecated. You should pass the gcp_conn_id parameter instead.
-    :type bigquery_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param labels: a dictionary containing labels for the job/query,
         passed to BigQuery
-    :type labels: dict
     :param encryption_configuration: [Optional] Custom encryption configuration (e.g., Cloud KMS keys).
         **Example**: ::
 
             encryption_configuration = {
                 "kmsKeyName": "projects/testp/locations/us/keyRings/test-kr/cryptoKeys/test-key"
             }
-    :type encryption_configuration: dict
     :param location: The location used for the operation.
-    :type location: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -76,7 +65,6 @@ class BigQueryToBigQueryOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -87,6 +75,7 @@ class BigQueryToBigQueryOperator(BaseOperator):
     )
     template_ext: Sequence[str] = ('.sql',)
     ui_color = '#e6f0e4'
+    operator_extra_links = (BigQueryTableLink(),)
 
     def __init__(
         self,
@@ -96,7 +85,6 @@ class BigQueryToBigQueryOperator(BaseOperator):
         write_disposition: str = 'WRITE_EMPTY',
         create_disposition: str = 'CREATE_IF_NEEDED',
         gcp_conn_id: str = 'google_cloud_default',
-        bigquery_conn_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
         labels: Optional[Dict] = None,
         encryption_configuration: Optional[Dict] = None,
@@ -106,15 +94,6 @@ class BigQueryToBigQueryOperator(BaseOperator):
     ) -> None:
         super().__init__(**kwargs)
 
-        if bigquery_conn_id:
-            warnings.warn(
-                "The bigquery_conn_id parameter has been deprecated. You should pass "
-                "the gcp_conn_id parameter.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            gcp_conn_id = bigquery_conn_id
-
         self.source_project_dataset_tables = source_project_dataset_tables
         self.destination_project_dataset_table = destination_project_dataset_table
         self.write_disposition = write_disposition
@@ -133,18 +112,29 @@ class BigQueryToBigQueryOperator(BaseOperator):
             self.destination_project_dataset_table,
         )
         hook = BigQueryHook(
-            bigquery_conn_id=self.gcp_conn_id,
+            gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
             location=self.location,
             impersonation_chain=self.impersonation_chain,
         )
-        conn = hook.get_conn()
-        cursor = conn.cursor()
-        cursor.run_copy(
-            source_project_dataset_tables=self.source_project_dataset_tables,
-            destination_project_dataset_table=self.destination_project_dataset_table,
-            write_disposition=self.write_disposition,
-            create_disposition=self.create_disposition,
-            labels=self.labels,
-            encryption_configuration=self.encryption_configuration,
-        )
+
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", DeprecationWarning)
+            job_id = hook.run_copy(
+                source_project_dataset_tables=self.source_project_dataset_tables,
+                destination_project_dataset_table=self.destination_project_dataset_table,
+                write_disposition=self.write_disposition,
+                create_disposition=self.create_disposition,
+                labels=self.labels,
+                encryption_configuration=self.encryption_configuration,
+            )
+
+            job = hook.get_job(job_id=job_id).to_api_repr()
+            conf = job["configuration"]["copy"]["destinationTable"]
+            BigQueryTableLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=conf["datasetId"],
+                project_id=conf["projectId"],
+                table_id=conf["tableId"],
+            )
